@@ -60,30 +60,36 @@ class A3eActionEditor {
             try {
                 CenteredVRML vrml = new CenteredVRML(urlString);
                 Vector3d loc = new Vector3d();
-                Vector3d boneOffset1 = null;
+                Vector3d bvhOffset = null; //BVHデータから来る骨のオフセット
                 if (currentSkeleton!=null)
-                    boneOffset1 = currentSkeleton.getOffset(p.getName());
-                if (boneOffset1!=null)
-                    loc.add(boneOffset1);
+                    bvhOffset = currentSkeleton.getOffset(p.getName());
+                else
+                    bvhOffset = new Vector3d();
                 s = p.getOffset();
                 x = Double.parseDouble(s.split("\\s")[0]);
                 y = Double.parseDouble(s.split("\\s")[1]);
                 z = Double.parseDouble(s.split("\\s")[2]);
-                Vector3d boneOffset2 = new Vector3d(x,y,z);
-                loc.add(boneOffset2);
-                loc.scale(actionScale);
-                loc.add(actionOffset);
-                loc = Util.trans(actionQuat,loc);
+                Vector3d boneOffset = new Vector3d(x,y,z);//CATALOG.XMLから来る骨のオフセット
                 s = p.getRot();
                 x = Double.parseDouble(s.split("\\s")[0])/180.0*Math.PI;
                 y = Double.parseDouble(s.split("\\s")[1])/180.0*Math.PI;
                 z = Double.parseDouble(s.split("\\s")[2])/180.0*Math.PI;
-                Quat4d boneQuat = Util.euler2quat(x,y,z);
-                boneQuat.mul(actionQuat);
-                double boneScale = actionScale*p.getScale();
-                vrml.setQuat(boneQuat);
-                vrml.setScale(boneScale);
+                Quat4d boneQuat = Util.euler2quat(x,y,z);//CATALOC.XMLから来る骨の回転
+                double boneScale = p.getScale();//CATALOG.XMLから来る骨のスケール
+
+                loc.add(boneOffset);
+                loc.add(bvhOffset);
+                loc.scale(actionScale);
+                loc = Util.trans(actionQuat,loc);
+                loc.add(actionOffset);
+                Quat4d quat = new Quat4d();
+                quat.mul(actionQuat,boneQuat);
+                double scale = boneScale*actionScale;
+
+                vrml.setQuat(quat);
+                vrml.setScale(scale);
                 vrml.setLoc2(loc);
+
                 vrmls.put(p.getName(),vrml);
             } catch (Exception e) {
                 e.printStackTrace();
@@ -249,6 +255,12 @@ class A3eActionEditor {
         String fileName = fileManager.path2FileName(bvhFilePath);
         return fileName;
     }
+    A3eFile getBVHFile() {
+        String bvhFilePath = currentAction.getBvh();
+        if (bvhFilePath!=null)
+            return fileManager.getA3eFileFromPath(bvhFilePath);
+        return A3eFile.noneFile;
+    }
     void setBVH(A3eFile file) {
         String an = currentAction.getAn();
         int i = catalog.a3.getA().indexOf(currentAction);
@@ -414,18 +426,22 @@ class A3eActionEditor {
     void removeSoundDate() {
         currentAction.setS(null);
     }
-    String getSoundFile() {
+    A3eFile getSoundFile() {
         S s = currentAction.getS();
         if (s==null)
-            return null;
-        else
-            return currentAction.getS().getFile();
+            return A3eFile.noneFile;
+        String sf = currentAction.getS().getFile();
+        A3eFile f = fileManager.getA3eFileFromPath(sf);
+        if (f!=null)
+            return f;
+        return A3eFile.noneFile;
     }
     void setSoundFile(A3eFile file) {
         S s = currentAction.getS();
         if (s==null) {
             s = new S();
             s.setFile(file.getPath());
+            s.setType(SoundType.POINT_SOUND);
             currentAction.setS(s);
         }
         s.setFile(file.getPath());
@@ -542,32 +558,32 @@ class A3eActionEditor {
         Vector3d actionLoc;
         Quat4d actionQuatRev;
         double actionScale;
-        Vector3d boneOffset1;
+        Vector3d bvhOffset;
         if (currentSkeleton!=null) {
             actionLoc = currentSkeleton.getLoc();
             actionQuatRev = currentSkeleton.getQuat();
             actionQuatRev.conjugate();
             actionScale = currentSkeleton.getScale();
-            boneOffset1 = currentSkeleton.getOffset(bn);
+            bvhOffset = currentSkeleton.getOffset(bn);
         } else {
             actionLoc = new Vector3d();
             actionQuatRev = new Quat4d(0.0,0.0,0.0,1.0);
             actionScale = 1.0;
-            boneOffset1 = new Vector3d();
+            bvhOffset = new Vector3d();
         }
         for (P p:currentAction.getP()) {
             if (p.getName().equals(bn)) {
                 CenteredVRML vrml = vrmls.get(bn);
                 Vector3d v = vrml.getLoc2();
-                v = Util.trans(actionQuatRev,v);
                 v.sub(actionLoc);
                 v.scale(1.0/actionScale);
-                if (boneOffset1!=null)
-                    v.sub(boneOffset1);
+                v = Util.trans(actionQuatRev,v);
+                v.sub(bvhOffset);
                 String s = ""+v.x+" "+v.y+" "+v.z;
                 p.setOffset(s);
+
                 Quat4d boneQuat = vrml.getQuat();
-                boneQuat.mul(actionQuatRev);
+                boneQuat.mul(actionQuatRev,boneQuat);
                 v = Util.quat2euler(boneQuat);
                 s = ""+180.0*v.x/Math.PI+" "+180.0*v.y/Math.PI+" "+180.0*v.z/Math.PI;
                 p.setRot(s);
